```
usage: zik-dl [-h] [--artist ARTIST] [--album ALBUM] url

Command-line program to download music from YouTube and other websites.

positional arguments:
  url              URL of the song/album to download

optional arguments:
  -h, --help       show this help message and exit
  --artist ARTIST  artist name
  --album ALBUM    album name
```
